@@ -1,8 +1,6 @@
-"""
-Test deconvolution
-"""
-import pytest
 import numpy as np
+import pytest
+
 import sunpy.data.test
 import sunpy.map
 
@@ -16,7 +14,7 @@ def test_deconvolve(aia_171_map):
     try:
         import cupy  # NOQA
     except ImportError:
-        pytest.skip('Cannot import cupy. Skipping deconvolution test with full PSF')
+        pytest.skip("Cannot import cupy. Skipping deconvolution test with full PSF")
     map_decon = aiapy.psf.deconvolve(aia_171_map)
     assert isinstance(map_decon, sunpy.map.GenericMap)
     assert map_decon.data.shape == aia_171_map.data.shape
@@ -34,7 +32,7 @@ def test_deconvolve_negative_pixels(aia_171_map, psf):
         aia_171_map.meta,
     )
     with pytest.warns(AiapyUserWarning):
-        _ = aiapy.psf.deconvolve(
+        aiapy.psf.deconvolve(
             aia_171_map_neg,
             psf=psf,
             iterations=1,
